@@ -19,9 +19,21 @@
 
 
 from .metric import get_metric
-from .volatility import BaseVolatilityEstimator, TrainTestVolatility, BootstrappedVolatility, SplitSeedVolatility
+from .volatility import (
+    BaseVolatilityEstimator,
+    TrainTestVolatility,
+    BootstrappedVolatility,
+    SplitSeedVolatility,
+)
 from .utils import sample_data, check_sampling_input
 
 
-__all__ = ['get_metric', 'BaseVolatilityEstimator', 'TrainTestVolatility', 'BootstrappedVolatility',
-           'SplitSeedVolatility', 'sample_data', 'check_sampling_input']
+__all__ = [
+    "get_metric",
+    "BaseVolatilityEstimator",
+    "TrainTestVolatility",
+    "BootstrappedVolatility",
+    "SplitSeedVolatility",
+    "sample_data",
+    "check_sampling_input",
+]
